@@ -117,7 +117,7 @@ class EQSNBackend(object):
         self._hosts = EQSNBackend.Hosts.get_instance()
         # keys are from : to, where from is the host calling create EPR
         self._entaglement_qubits = EQSNBackend.EntanglementIDs.get_instance()
-        self.eqsn = EQSN()
+        self.eqsn = EQSN.get_instance()
 
     def start(self, **kwargs):
         """
@@ -352,6 +352,38 @@ class EQSNBackend(object):
         """
         self.eqsn.cphase_gate(target.qubit, qubit.qubit)
 
+    def custom_gate(self, qubit, gate):
+        """
+        Applies a custom gate to the qubit.
+
+        Args:
+            qubit(Qubit): Qubit to which the gate is applied.
+            gate(np.ndarray): 2x2 array of the gate.
+        """
+        self.eqsn.custom_gate(qubit.qubit, gate)
+
+    def custom_controlled_gate(self, qubit, target, gate):
+        """
+        Applies a custom gate to the target qubit, controlled by the qubit.
+
+        Args:
+            qubit(Qubit): Qubit to control the gate.
+            target(Qubit): Qubit on which the gate is applied.
+            gate(nd.array): 2x2 array for the gate applied to target.
+        """
+        self.eqsn.custom_controlled_gate(target.qubit, qubit.qubit, gate)
+
+    def custom_two_qubit_gate(self, qubit1, qubit2, gate):
+        """
+        Applies a custom two qubit gate to qubit1 \\otimes qubit2.
+
+        Args:
+            qubit1(Qubit): First qubit of the gate.
+            qubit2(Qubit): Second qubit of the gate.
+            gate(np.ndarray): 4x4 array for the gate applied.
+        """
+        self.eqsn.custom_two_qubit_gate(qubit1.qubit, qubit2.qubit, gate)
+
     def measure(self, qubit, non_destructive):
         """
         Perform a measurement on a qubit.
