@@ -1,3 +1,5 @@
+import time
+
 from backends.SafeDict import SafeDict
 from objects.qubit import Qubit
 from queue import Queue
@@ -15,6 +17,7 @@ class ProjectQBackend(object):
         self._hosts = ProjectQBackend.Hosts.get_instance()
         self._entaglement_pairs = ProjectQBackend.EntanglementPairs.get_instance()
         self.engine = projectq.MainEngine()
+        self.measuring = False
 
     def __del__(self):
         self.engine.flush(deallocate_qubits=True)
@@ -277,6 +280,38 @@ class ProjectQBackend(object):
         """
         projectq.ops.CZ | (control.qubit, target.qubit)
 
+    def custom_gate(self, qubit, gate):
+        """
+        Applies a custom gate to the qubit.
+
+        Args:
+            qubit(Qubit): Qubit to which the gate is applied.
+            gate(np.ndarray): 2x2 array of the gate.
+        """
+        raise (EnvironmentError("Not implemented for this backend!"))
+
+    def custom_controlled_gate(self, qubit, target, gate):
+        """
+        Applies a custom gate to the target qubit, controlled by the qubit.
+
+        Args:
+            qubit(Qubit): Qubit to control the gate.
+            target(Qubit): Qubit on which the gate is applied.
+            gate(nd.array): 2x2 array for the gate applied to target.
+        """
+        raise (EnvironmentError("Not implemented for this backend!"))
+
+    def custom_two_qubit_gate(self, qubit1, qubit2, gate):
+        """
+        Applies a custom two qubit gate to qubit1 \\otimes qubit2.
+
+        Args:
+            qubit1(Qubit): First qubit of the gate.
+            qubit2(Qubit): Second qubit of the gate.
+            gate(np.ndarray): 4x4 array for the gate applied.
+        """
+        raise (EnvironmentError("Not implemented for this backend!"))
+
     def measure(self, qubit, non_destructive):
         """
         Perform a measurement on a qubit.
@@ -289,14 +324,18 @@ class ProjectQBackend(object):
         Returns:
             The value which has been measured.
         """
+        while self.measuring:
+            time.sleep(0.1)
+            pass
+
+        self.measuring = True
         projectq.ops.Measure | qubit.qubit
         m = int(qubit.qubit)
 
-        # TODO: This causes threading issues
-        # if not non_destructive:
-        #     self.release(qubit)
-        #     self.engine.flush()
-
+        if not non_destructive:
+            self.release(qubit)
+            self.engine.flush()
+        self.measuring = False
         return m
 
     def release(self, qubit):
